// Copyright 2021 tison <wander4096@gmail.com>.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

use algorona::lower_bound;

#[test]
fn test_lower_bound() {
    assert_eq!(lower_bound(vec![1, 1, 1, 3], 0), 0);
    assert_eq!(lower_bound(vec![1, 1, 1, 3], 1), 0);
    assert_eq!(lower_bound(vec![1, 1, 1, 3], 2), 3);
    assert_eq!(lower_bound(vec![1, 1, 1, 3], 3), 3);
    assert_eq!(lower_bound(vec![1, 1, 1, 3], 4), 4);
}
